;; Generated package description from orgit.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "orgit" "2.2.1.0.20260731.0" "Support for Org links to Magit buffers" '((emacs "29.1") (compat "31.0") (cond-let "1.1") (llama "1.0") (magit "4.7") (org "9.8")) :commit "c948819a7cad37a654ada275ebf7c003abf782d0" :authors '(("Jonas Bernoulli" . "emacs.orgit@jonas.bernoulli.dev")) :maintainer '("Jonas Bernoulli" . "emacs.orgit@jonas.bernoulli.dev") :keywords '("hypermedia" "vc") :url "https://github.com/magit/orgit")
